@@ -24,6 +24,8 @@ pub const PACKET_PRODUCER_CODE: u16 = 0x0001;
 pub const MESSAGE_PRODUCER_CODE: u16 = 0x0002;
 pub const BCM_CHANGE_BRIGHTNESS_PRODUCER_CODE: u16 = 0x0003;
 pub const BCM_CHANGE_BRIGHTNESS_STATE_PRODUCER_CODE: u16 = 0x0004;
+pub const BCM_ANIMATE_BRIGHTNESS_PRODUCER_CODE: u16 = 0x0005;
+pub const BCM_ANIMATE_BRIGHTNESS_STATE_PRODUCER_CODE: u16 = 0x0006;
 
 #[derive(Debug, PartialEq)]
 pub enum ProducerError {
